/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * A location where a voter can vote. This may be an early vote site or an election day voting
 * location.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PollingLocation extends GenericJson {

  /**
   * The address of the location
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SimpleAddressType address;

  /**
   * The last date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String endDate;

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The name of the early vote site. This field is not populated for polling locations.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Notes about this location (e.g. accessibility ramp or entrance to use)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String notes;

  /**
   * A description of when this location is open.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String pollingHours;

  /**
   * A list of sources for this location. If multiple sources are listed the data has been
   * aggregated from those sources.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Source> sources;

  static {
    // hack to force ProGuard to consider Source used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Source.class);
  }

  /**
   * The first date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String startDate;

  /**
   * The services provided by this early vote site. This field is not populated for polling
   * locations.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String voterServices;

  /**
   * The address of the location
   * The value returned may be {@code null}.
   */
  public SimpleAddressType getAddress() {
    return address;
  }

  /**
   * The address of the location
   * The value set may be {@code null}.
   */
  public PollingLocation setAddress(SimpleAddressType address) {
    this.address = address;
    return this;
  }

  /**
   * The last date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value returned may be {@code null}.
   */
  public String getEndDate() {
    return endDate;
  }

  /**
   * The last date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value set may be {@code null}.
   */
  public PollingLocation setEndDate(String endDate) {
    this.endDate = endDate;
    return this;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value set may be {@code null}.
   */
  public PollingLocation setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The name of the early vote site. This field is not populated for polling locations.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the early vote site. This field is not populated for polling locations.
   * The value set may be {@code null}.
   */
  public PollingLocation setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Notes about this location (e.g. accessibility ramp or entrance to use)
   * The value returned may be {@code null}.
   */
  public String getNotes() {
    return notes;
  }

  /**
   * Notes about this location (e.g. accessibility ramp or entrance to use)
   * The value set may be {@code null}.
   */
  public PollingLocation setNotes(String notes) {
    this.notes = notes;
    return this;
  }

  /**
   * A description of when this location is open.
   * The value returned may be {@code null}.
   */
  public String getPollingHours() {
    return pollingHours;
  }

  /**
   * A description of when this location is open.
   * The value set may be {@code null}.
   */
  public PollingLocation setPollingHours(String pollingHours) {
    this.pollingHours = pollingHours;
    return this;
  }

  /**
   * A list of sources for this location. If multiple sources are listed the data has been
   * aggregated from those sources.
   * The value returned may be {@code null}.
   */
  public java.util.List<Source> getSources() {
    return sources;
  }

  /**
   * A list of sources for this location. If multiple sources are listed the data has been
   * aggregated from those sources.
   * The value set may be {@code null}.
   */
  public PollingLocation setSources(java.util.List<Source> sources) {
    this.sources = sources;
    return this;
  }

  /**
   * The first date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value returned may be {@code null}.
   */
  public String getStartDate() {
    return startDate;
  }

  /**
   * The first date that this early vote site may be used. This field is not populated for polling
   * locations.
   * The value set may be {@code null}.
   */
  public PollingLocation setStartDate(String startDate) {
    this.startDate = startDate;
    return this;
  }

  /**
   * The services provided by this early vote site. This field is not populated for polling
   * locations.
   * The value returned may be {@code null}.
   */
  public String getVoterServices() {
    return voterServices;
  }

  /**
   * The services provided by this early vote site. This field is not populated for polling
   * locations.
   * The value set may be {@code null}.
   */
  public PollingLocation setVoterServices(String voterServices) {
    this.voterServices = voterServices;
    return this;
  }

}
